@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: create_pages.py 9850 2017-04-08 14:24:13Z Lavender $
+# $Id: create_pages.py 9976 2017-05-16 06:31:28Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2017-04-08 22:24:13 +0800 (週六, 08 四月 2017) $
-# $Revision: 9850 $
+# $Date: 2017-05-16 14:31:28 +0800 (週二, 16 五月 2017) $
+# $Revision: 9976 $
 
 import os
 import logging
@@ -23,6 +23,8 @@ from django.conf import settings
 from django.db import transaction
 from cms.api import create_page
 
+from Zephyrus.boilerplate.management.commands import TEMPLATES_DIR_PATH
+
 logger = logging.getLogger(__name__)
 logger.setLevel(logging.DEBUG)
 handler = logging.StreamHandler()
@@ -30,12 +32,6 @@ handler.setFormatter(
     logging.Formatter("%(asctime)s - %(levelname)s - %(message)s"))
 logger.addHandler(handler)
 
-if hasattr(settings, 'TEMPLATES'):
-    TEMPLATES_DIR_PATH = settings.TEMPLATES[0]['DIRS'][0]
-else:
-    TEMPLATES_DIR_PATH = os.path.abspath(
-        os.path.join('.', 'templates'))
-
 class Command(BaseCommand):
 
     help = 'Auto create all pages.'
