@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: create_zip.py 9978 2017-05-20 15:24:37Z Lavender $
+# $Id: create_zip.py 9979 2017-05-20 16:33:56Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2017-05-20 23:24:37 +0800 (週六, 20 五月 2017) $
-# $Revision: 9978 $
+# $Date: 2017-05-21 00:33:56 +0800 (週日, 21 五月 2017) $
+# $Revision: 9979 $
 
 import os
 import logging
@@ -92,13 +92,13 @@ class Command(BaseCommand):
                 
         temp = get_template('boilerplate/py/setup.py')
         content = temp.render()
-        with open(os.path.join(ROOT_DIR_PATH, 'setup.py'), 'w') as f:
-            f.write(content)
+        with open(os.path.join(ROOT_DIR_PATH, 'setup.py'), 'wb') as f:
+            f.write(content.encode('utf8'))
             
         temp = get_template('boilerplate/txt/README.txt')
         content = temp.render()
         with open(os.path.join(ROOT_DIR_PATH, 'README.txt'), 'w') as f:
-            f.write(content)
+            f.write(content.encode('utf8'))
 
         zip.write('./README.txt')
         logger.info("Zip README.txt")
