@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: models.py 9868 2017-04-16 09:05:26Z Lavender $
+# $Id: models.py 9919 2017-04-27 07:05:09Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,11 +12,17 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2017-04-16 17:05:26 +0800 (週日, 16 四月 2017) $
-# $Revision: 9868 $
+# $Date: 2017-04-27 15:05:09 +0800 (週四, 27 四月 2017) $
+# $Revision: 9919 $
 
 from django.db import models
+from django.utils import timezone
 
 class Email(models.Model):
     email = models.EmailField()
     fromUrl = models.URLField()
+    date = models.DateTimeField(
+        auto_now_add=True)
+        
+    def __unicode__(self):
+        return u"%s From: %s (%s)" % (self.email, self.fromUrl, self.date)
